{# Project member listing tab
 # Copyright (C) 2021  Ngô Ngọc Đức Huy
 # Copyright (C) 2021  Ngô Xuân Minh
 #
 # This file is part of Acanban.
 #
 # Acanban is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as published
 # by the Free Software Foundation, either version 3 of the License, or
 # (at your option) any later version.
 #
 # Acanban is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU Affero General Public License for more details.
 #
 # You should have received a copy of the GNU Affero General Public License
 # along with Acanban.  If not, see <https://www.gnu.org/licenses/>.
 #}

{% extends 'project-tab.html' %}
{% block tabbarlayout %}
{{ tabbar('Members') }}
{% endblock %}

{% block tabcontent %}
<div class=col-wide>
  {% if error %}
  <div class=error>{{ error }}</div>
  {% endif %}
  <form action=invite method=POST>
    <label for=new-user>
    <input type=text id=new-user name="new-user"/>
    <button>Invite</button>
  </form>

  <h3>Supervisors</h3>
  <ul>
    {% for supervisor in project.supervisors %}
    <li>{{ supervisor|userlink|safe }}</li>
    {% endfor %}
  </ul>
  <h3>Students</h3>
  <ul>
    {% for student in project.students %}
    <li>{{ student|userlink|safe }}</li>
    {% endfor %}
  </ul>
</div>
{% endblock %}
