from typing import Any, AsyncContextManager

class Connection: ...

class TrioConnectionPool:
    def __init__(self, *args: Any, **kwargs: Any) -> None: ...
    async def connection(self) -> AsyncContextManager[Connection]: ...
    async def close(self) -> None: ...
