#!/usr/bin/env python
# setup.py generated by flit for tools that don't yet use PEP 517

from distutils.core import setup

packages = \
['acanban']

package_data = \
{'': ['*'], 'acanban': ['static/*', 'templates/*']}

package_dir = \
{'': 'src'}

install_requires = \
['appdirs',
 'bleach',
 'bleach_allowlist',
 'httpx',
 'humanize',
 'hypercorn',
 'markdown',
 'py-cid',
 'quart-auth',
 'quart-trio-twice',
 'rethinkdb >=2.4.8']

setup(name='acanban',
      version='0.1.0',
      description='Academic Kanban',
      author='Ngô Ngọc Đức Huy',
      author_email='duchuy29092000@gmail.com',
      url='https://Huy-Ngo.github.io/acanban',
      packages=packages,
      package_data=package_data,
      package_dir=package_dir,
      install_requires=install_requires,
      python_requires='>=3.7',
     )
